<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="%{APPNAMELC}part" version="1">
<MenuBar>
  <Menu name="file">
    <Action name="file_save"/>
    <Action name="file_save_as"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="file_save"/>
  <Separator/>
</ToolBar>
</gui>
