<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="NotepadPart" version="2">
<MenuBar>
 <Menu name="file"><text>&amp;File</text>
  <Menu name="NotepadSubMenu"><text>Notepad Stuff</text>
    <Action name="searchreplace"/>
  </Menu>
 </Menu>
 <Menu name="edit"><text>&amp;Edit</text>
  <Action name="searchreplace"/>
 </Menu>
</MenuBar>
</gui>
